### AMPL Python Tools

This package includes tools to use with AMPL and amplpy.

#### Repositories

- GitHub Repository: https://github.com/ampl/amplpy/tree/master/ampltools
- PyPI Repository: https://pypi.python.org/pypi/ampltools

#### Setup

Install from the [repository](https://pypi.python.org/pypi/ampltools):
```
$ python -m pip install ampltools
```

#### License

BSD-3

***
Copyright © 2023 AMPL Optimization inc. All rights reserved.
